@@ -32,7 +32,9 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
+import org.apache.maven.RepositoryUtils;
 import org.apache.maven.artifact.Artifact;
+import org.apache.maven.artifact.ArtifactUtils;
 import org.apache.maven.artifact.factory.ArtifactFactory;
 import org.apache.maven.artifact.metadata.ArtifactMetadataRetrievalException;
 import org.apache.maven.artifact.metadata.ArtifactMetadataSource;
@@ -47,15 +49,16 @@ import org.apache.maven.artifact.resolver.ArtifactResolutionException;
 import org.apache.maven.artifact.resolver.MultipleArtifactsNotFoundException;
 import org.apache.maven.artifact.resolver.filter.AndArtifactFilter;
 import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
-import org.apache.maven.artifact.resolver.filter.ExcludesArtifactFilter;
+import org.apache.maven.artifact.resolver.filter.ExclusionArtifactFilter;
 import org.apache.maven.artifact.versioning.ArtifactVersion;
 import org.apache.maven.artifact.versioning.DefaultArtifactVersion;
 import org.apache.maven.artifact.versioning.InvalidVersionSpecificationException;
 import org.apache.maven.artifact.versioning.VersionRange;
+import org.apache.maven.execution.MavenSession;
 import org.apache.maven.model.Dependency;
 import org.apache.maven.model.DependencyManagement;
 import org.apache.maven.model.DistributionManagement;
-import org.apache.maven.model.Exclusion;
+import org.apache.maven.model.Model;
 import org.apache.maven.model.Relocation;
 import org.apache.maven.model.building.ModelBuildingException;
 import org.apache.maven.model.building.ModelBuildingRequest;
@@ -69,6 +72,7 @@ import org.apache.maven.project.ProjectBuildingException;
 import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.properties.internal.EnvironmentUtils;
 import org.apache.maven.properties.internal.SystemProperties;
+import org.apache.maven.repository.internal.MavenWorkspaceReader;
 import org.apache.maven.repository.legacy.metadata.DefaultMetadataResolutionRequest;
 import org.apache.maven.repository.legacy.metadata.MetadataResolutionRequest;
 import org.codehaus.plexus.PlexusContainer;
@@ -78,6 +82,7 @@ import org.codehaus.plexus.component.repository.exception.ComponentLookupExcepti
 import org.codehaus.plexus.logging.Logger;
 import org.eclipse.aether.RepositorySystemSession;
 import org.eclipse.aether.repository.RepositoryPolicy;
+import org.eclipse.aether.repository.WorkspaceReader;
 import org.eclipse.aether.transfer.ArtifactNotFoundException;
 
 /**
@@ -175,9 +180,25 @@ public class MavenMetadataSource
 
         Artifact relocatedArtifact = null;
 
-        //TODO Not even sure this is really required as the project will be cached in the builder, we'll see this
-        // is currently the biggest hotspot
-        if ( artifact instanceof ArtifactWithDependencies )
+        final WorkspaceReader workspace = legacySupport.getRepositorySession().getWorkspaceReader();
+        Model model = null;
+        if ( workspace instanceof MavenWorkspaceReader )
+        {
+            model = ( (MavenWorkspaceReader) workspace ).findModel( RepositoryUtils.toArtifact( artifact ) );
+        }
+
+        if ( model != null )
+        {
+            pomArtifact = artifact;
+            dependencies = model.getDependencies();
+            DependencyManagement dependencyManagement = model.getDependencyManagement();
+            managedDependencies = dependencyManagement == null ? null : dependencyManagement.getDependencies();
+            MavenSession session = legacySupport.getSession();
+            MavenProject project = session.getProjectMap().get(
+                ArtifactUtils.key( artifact.getGroupId(), artifact.getArtifactId(), artifact.getVersion() ) );
+            pomRepositories = project.getRemoteArtifactRepositories();
+        }
+        else if ( artifact instanceof ArtifactWithDependencies )
         {
             pomArtifact = artifact;
 
@@ -394,14 +415,7 @@ public class MavenMetadataSource
 
         if ( !dependency.getExclusions().isEmpty() )
         {
-            List<String> exclusions = new ArrayList<>();
-
-            for ( Exclusion e : dependency.getExclusions() )
-            {
-                exclusions.add( e.getGroupId() + ':' + e.getArtifactId() );
-            }
-
-            effectiveFilter = new ExcludesArtifactFilter( exclusions );
+            effectiveFilter = new ExclusionArtifactFilter( dependency.getExclusions() );
 
             if ( inheritedFilter != null )
             {
