@@ -27,13 +27,14 @@ import org.apache.maven.model.building.DefaultModelBuildingRequest;
 import org.apache.maven.model.building.ModelBuildingRequest;
 import org.apache.maven.model.building.SimpleProblemCollector;
 import org.apache.maven.model.io.xpp3.MavenXpp3Reader;
-import org.codehaus.plexus.PlexusTestCase;
+
+import junit.framework.TestCase;
 
 /**
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
  */
 public class DefaultModelValidatorTest
-    extends PlexusTestCase
+    extends TestCase
 {
 
     private ModelValidator validator;
@@ -94,7 +95,7 @@ public class DefaultModelValidatorTest
     {
         super.setUp();
 
-        validator = lookup( ModelValidator.class );
+        validator = new DefaultModelValidator();
     }
 
     @Override
@@ -129,9 +130,9 @@ public class DefaultModelValidatorTest
         SimpleProblemCollector result =
             validateRaw( "bad-modelVersion.xml", ModelBuildingRequest.VALIDATION_LEVEL_STRICT );
 
-        assertViolations( result, 0, 1, 0 );
+        assertViolations( result, 1, 0, 0 );
 
-        assertTrue( result.getErrors().get( 0 ).contains( "modelVersion" ) );
+        assertTrue( result.getFatals().get( 0 ).contains( "modelVersion" ) );
     }
 
     public void testMissingArtifactId()
@@ -294,11 +295,11 @@ public class DefaultModelValidatorTest
 
         assertEquals( "'repositories.repository.id' is missing.", result.getErrors().get( 0 ) );
 
-        assertEquals( "'repositories.repository[null].url' is missing.", result.getErrors().get( 1 ) );
+        assertEquals( "'repositories.repository.[null].url' is missing.", result.getErrors().get( 1 ) );
 
         assertEquals( "'pluginRepositories.pluginRepository.id' is missing.", result.getErrors().get( 2 ) );
 
-        assertEquals( "'pluginRepositories.pluginRepository[null].url' is missing.", result.getErrors().get( 3 ) );
+        assertEquals( "'pluginRepositories.pluginRepository.[null].url' is missing.", result.getErrors().get( 3 ) );
     }
 
     public void testMissingResourceDirectory()
@@ -339,6 +340,16 @@ public class DefaultModelValidatorTest
         assertTrue( result.getWarnings().get( 1 ).contains( "test:g" ) );
     }
 
+    public void testBadDependencyManagementScope()
+        throws Exception
+    {
+        SimpleProblemCollector result = validate( "bad-dependency-management-scope.xml" );
+
+        assertViolations( result, 0, 0, 1 );
+
+        assertContains( result.getWarnings().get( 0 ), "test:g" );
+    }
+
     public void testBadDependencyVersion()
         throws Exception
     {
@@ -724,7 +735,7 @@ public class DefaultModelValidatorTest
 
         assertViolations( result, 1, 0, 0 );
 
-        assertEquals( "'dependencies.dependency com.example.group:testinvalidpom:0.0.1-SNAPSHOT' for com.example.group:testinvalidpom:0.0.1-SNAPSHOT is referencing itself.",
+        assertEquals( "'dependencies.dependency[com.example.group:testinvalidpom:0.0.1-SNAPSHOT]' for com.example.group:testinvalidpom:0.0.1-SNAPSHOT is referencing itself.",
                       result.getFatals().get( 0 ) );
 
     }
